@@ -47,7 +47,13 @@ class Configuration(object):
         },
         'processes': {
 
-        }
+        },
+        'sendfile': {
+
+        },
+        'environment': {
+
+        },
     }
     def load_sites(self, config_file_content=None, env_dict=None):
         """
@@ -121,6 +127,9 @@ class Configuration(object):
                     attr_dict["django"]["args"].append(" --settings=%s" % ('_gen.settings', ))
 
             attr_dict.update({'processes': self.processes(site, env_dict)})
+            attr_dict['environment'] = self.environment(site, env_dict)
+            attr_dict['environment'].setdefault('DEPLOYMENT_SITE', site)
+            attr_dict['identifier'] = env_dict.identifier
             self._sites[site] = _AttributeDict(attr_dict)
         return self._sites
 
@@ -209,6 +218,10 @@ class Configuration(object):
 
         return process_dict
 
+    def environment(self, site, env_dict):
+        site_dict = self.sites[site]
+        return site_dict['environment']
+
     def deployment(self, site, env_dict):
         """
         Here we add the information from deployments.py and merge it into our site dictionaries.
@@ -258,7 +271,7 @@ class Configuration(object):
             print(DOMAIN_DICT_DEPRECATION_WARNING)
         elif type(env_dict.get("domains")) == dict:
             domains = env_dict.get("domains")
-        elif env_dict.get("domains") == None:
+        elif env_dict.get("domains") is None:
             domains = {
                 "main": [],
             }
